# Changelog

## [stormi-v0.1.3](https://github.com/pinellolab/stormi/compare/stormi-v0.1.2...stormi-v0.1.3) (2025-03-19)

### Bug Fixes

* **ATAC_RNA:** sample_prior function disappeared somehow after recent commits and now I put it back ([41a14d9](https://github.com/pinellolab/stormi/commit/41a14d9277ac7ef586e8d36fa399609ee456325f))
* **RNA_1layer:** change import statement after recent changes for sde model ([1eaa947](https://github.com/pinellolab/stormi/commit/1eaa947157ac074ab388e4d49ae09452924cbc20))
* **solve_DE:** compatibility with non-SDE models ([888f50a](https://github.com/pinellolab/stormi/commit/888f50a9e96c351f90dd3bd8bc127f52c6fde3dd))
